@@ -1,5 +1,7 @@
 from __future__ import annotations
 
+import typing as t
+
 from sqlglot import exp, generator, parser, tokens, transforms
 from sqlglot.dialects.dialect import (
     Dialect,
@@ -22,14 +24,14 @@ from sqlglot.helper import seq_get
 from sqlglot.tokens import TokenType
 
 
-def _show_parser(*args, **kwargs):
-    def _parse(self):
+def _show_parser(*args: t.Any, **kwargs: t.Any) -> t.Callable[[MySQL.Parser], exp.Show]:
+    def _parse(self: MySQL.Parser) -> exp.Show:
         return self._parse_show_mysql(*args, **kwargs)
 
     return _parse
 
 
-def _date_trunc_sql(self, expression):
+def _date_trunc_sql(self: generator.Generator, expression: exp.DateTrunc) -> str:
     expr = self.sql(expression, "this")
     unit = expression.text("unit")
 
@@ -55,17 +57,17 @@ def _date_trunc_sql(self, expression):
     return f"STR_TO_DATE({concat}, '{date_format}')"
 
 
-def _str_to_date(args):
+def _str_to_date(args: t.List) -> exp.StrToDate:
     date_format = MySQL.format_time(seq_get(args, 1))
     return exp.StrToDate(this=seq_get(args, 0), format=date_format)
 
 
-def _str_to_date_sql(self, expression):
+def _str_to_date_sql(self: generator.Generator, expression: exp.StrToDate | exp.StrToTime) -> str:
     date_format = self.format_time(expression)
     return f"STR_TO_DATE({self.sql(expression.this)}, {date_format})"
 
 
-def _trim_sql(self, expression):
+def _trim_sql(self: generator.Generator, expression: exp.Trim) -> str:
     target = self.sql(expression, "this")
     trim_type = self.sql(expression, "position")
     remove_chars = self.sql(expression, "expression")
@@ -80,8 +82,8 @@ def _trim_sql(self, expression):
     return f"TRIM({trim_type}{remove_chars}{from_part}{target})"
 
 
-def _date_add_sql(kind):
-    def func(self, expression):
+def _date_add_sql(kind: str) -> t.Callable[[generator.Generator, exp.DateAdd | exp.DateSub], str]:
+    def func(self: generator.Generator, expression: exp.DateAdd | exp.DateSub) -> str:
         this = self.sql(expression, "this")
         unit = expression.text("unit").upper() or "DAY"
         return (
@@ -92,10 +94,10 @@ def _date_add_sql(kind):
 
 
 class MySQL(Dialect):
-    time_format = "'%Y-%m-%d %T'"
+    TIME_FORMAT = "'%Y-%m-%d %T'"
 
     # https://prestodb.io/docs/current/functions/datetime.html#mysql-date-functions
-    time_mapping = {
+    TIME_MAPPING = {
         "%M": "%B",
         "%c": "%-m",
         "%e": "%-d",
@@ -121,12 +123,19 @@ class MySQL(Dialect):
         KEYWORDS = {
             **tokens.Tokenizer.KEYWORDS,
             "CHARSET": TokenType.CHARACTER_SET,
+            "FORCE": TokenType.FORCE,
+            "IGNORE": TokenType.IGNORE,
             "LONGBLOB": TokenType.LONGBLOB,
             "LONGTEXT": TokenType.LONGTEXT,
             "MEDIUMBLOB": TokenType.MEDIUMBLOB,
             "MEDIUMTEXT": TokenType.MEDIUMTEXT,
             "SEPARATOR": TokenType.SEPARATOR,
+            "ENUM": TokenType.ENUM,
             "START": TokenType.BEGIN,
+            "SIGNED": TokenType.BIGINT,
+            "SIGNED INTEGER": TokenType.BIGINT,
+            "UNSIGNED": TokenType.UBIGINT,
+            "UNSIGNED INTEGER": TokenType.UBIGINT,
             "_ARMSCII8": TokenType.INTRODUCER,
             "_ASCII": TokenType.INTRODUCER,
             "_BIG5": TokenType.INTRODUCER,
@@ -176,23 +185,23 @@ class MySQL(Dialect):
         COMMANDS = tokens.Tokenizer.COMMANDS - {TokenType.SHOW}
 
     class Parser(parser.Parser):
-        FUNC_TOKENS = {*parser.Parser.FUNC_TOKENS, TokenType.SCHEMA, TokenType.DATABASE}  # type: ignore
+        FUNC_TOKENS = {*parser.Parser.FUNC_TOKENS, TokenType.SCHEMA, TokenType.DATABASE}
+        TABLE_ALIAS_TOKENS = (
+            parser.Parser.TABLE_ALIAS_TOKENS - parser.Parser.TABLE_INDEX_HINT_TOKENS
+        )
 
         FUNCTIONS = {
-            **parser.Parser.FUNCTIONS,  # type: ignore
+            **parser.Parser.FUNCTIONS,
             "DATE_ADD": parse_date_delta_with_interval(exp.DateAdd),
             "DATE_FORMAT": format_time_lambda(exp.TimeToStr, "mysql"),
             "DATE_SUB": parse_date_delta_with_interval(exp.DateSub),
             "INSTR": lambda args: exp.StrPosition(substr=seq_get(args, 1), this=seq_get(args, 0)),
-            "LEFT": lambda args: exp.Substring(
-                this=seq_get(args, 0), start=exp.Literal.number(1), length=seq_get(args, 1)
-            ),
             "LOCATE": locate_to_strposition,
             "STR_TO_DATE": _str_to_date,
         }
 
         FUNCTION_PARSERS = {
-            **parser.Parser.FUNCTION_PARSERS,  # type: ignore
+            **parser.Parser.FUNCTION_PARSERS,
             "GROUP_CONCAT": lambda self: self.expression(
                 exp.GroupConcat,
                 this=self._parse_lambda(),
@@ -201,7 +210,7 @@ class MySQL(Dialect):
         }
 
         STATEMENT_PARSERS = {
-            **parser.Parser.STATEMENT_PARSERS,  # type: ignore
+            **parser.Parser.STATEMENT_PARSERS,
             TokenType.SHOW: lambda self: self._parse_show(),
         }
 
@@ -280,9 +289,25 @@ class MySQL(Dialect):
             "SWAPS",
         }
 
+        TYPE_TOKENS = {
+            *parser.Parser.TYPE_TOKENS,
+            TokenType.SET,
+        }
+
+        ENUM_TYPE_TOKENS = {
+            *parser.Parser.ENUM_TYPE_TOKENS,
+            TokenType.SET,
+        }
+
         LOG_DEFAULTS_TO_LN = True
 
-        def _parse_show_mysql(self, this, target=False, full=None, global_=None):
+        def _parse_show_mysql(
+            self,
+            this: str,
+            target: bool | str = False,
+            full: t.Optional[bool] = None,
+            global_: t.Optional[bool] = None,
+        ) -> exp.Show:
             if target:
                 if isinstance(target, str):
                     self._match_text_seq(target)
@@ -338,10 +363,12 @@ class MySQL(Dialect):
                 offset=offset,
                 limit=limit,
                 mutex=mutex,
-                **{"global": global_},
+                **{"global": global_},  # type: ignore
             )
 
-        def _parse_oldstyle_limit(self):
+        def _parse_oldstyle_limit(
+            self,
+        ) -> t.Tuple[t.Optional[exp.Expression], t.Optional[exp.Expression]]:
             limit = None
             offset = None
             if self._match_text_seq("LIMIT"):
@@ -351,38 +378,30 @@ class MySQL(Dialect):
                 elif len(parts) == 2:
                     limit = parts[1]
                     offset = parts[0]
+
             return offset, limit
 
-        def _parse_set_item_charset(self, kind):
+        def _parse_set_item_charset(self, kind: str) -> exp.Expression:
             this = self._parse_string() or self._parse_id_var()
+            return self.expression(exp.SetItem, this=this, kind=kind)
 
-            return self.expression(
-                exp.SetItem,
-                this=this,
-                kind=kind,
-            )
-
-        def _parse_set_item_names(self):
+        def _parse_set_item_names(self) -> exp.Expression:
             charset = self._parse_string() or self._parse_id_var()
             if self._match_text_seq("COLLATE"):
                 collate = self._parse_string() or self._parse_id_var()
             else:
                 collate = None
-            return self.expression(
-                exp.SetItem,
-                this=charset,
-                collate=collate,
-                kind="NAMES",
-            )
+
+            return self.expression(exp.SetItem, this=charset, collate=collate, kind="NAMES")
 
     class Generator(generator.Generator):
         LOCKING_READS_SUPPORTED = True
         NULL_ORDERING_SUPPORTED = False
         JOIN_HINTS = False
-        TABLE_HINTS = False
+        TABLE_HINTS = True
 
         TRANSFORMS = {
-            **generator.Generator.TRANSFORMS,  # type: ignore
+            **generator.Generator.TRANSFORMS,
             exp.CurrentDate: no_paren_current_date_sql,
             exp.DateDiff: lambda self, e: self.func("DATEDIFF", e.this, e.expression),
             exp.DateAdd: _date_add_sql("ADD"),
@@ -419,13 +438,24 @@ class MySQL(Dialect):
         TYPE_MAPPING.pop(exp.DataType.Type.LONGBLOB)
 
         PROPERTIES_LOCATION = {
-            **generator.Generator.PROPERTIES_LOCATION,  # type: ignore
+            **generator.Generator.PROPERTIES_LOCATION,
             exp.TransientProperty: exp.Properties.Location.UNSUPPORTED,
             exp.VolatileProperty: exp.Properties.Location.UNSUPPORTED,
         }
 
         LIMIT_FETCH = "LIMIT"
 
+        def cast_sql(self, expression: exp.Cast, safe_prefix: t.Optional[str] = None) -> str:
+            """(U)BIGINT is not allowed in a CAST expression, so we use (UN)SIGNED instead."""
+            if expression.to.this == exp.DataType.Type.BIGINT:
+                to = "SIGNED"
+            elif expression.to.this == exp.DataType.Type.UBIGINT:
+                to = "UNSIGNED"
+            else:
+                return super().cast_sql(expression)
+
+            return f"CAST({self.sql(expression, 'this')} AS {to})"
+
         def show_sql(self, expression: exp.Show) -> str:
             this = f" {expression.name}"
             full = " FULL" if expression.args.get("full") else ""
@@ -468,9 +498,7 @@ class MySQL(Dialect):
 
         def _prefixed_sql(self, prefix: str, expression: exp.Expression, arg: str) -> str:
             sql = self.sql(expression, arg)
-            if not sql:
-                return ""
-            return f" {prefix} {sql}"
+            return f" {prefix} {sql}" if sql else ""
 
         def _oldstyle_limit_sql(self, expression: exp.Show) -> str:
             limit = self.sql(expression, "limit")
