@@ -1,10 +1,13 @@
 from __future__ import annotations
 
+import typing as t
+
 from sqlglot import exp, generator, parser, tokens, transforms
 from sqlglot.dialects.dialect import (
     Dialect,
     arrow_json_extract_scalar_sql,
     arrow_json_extract_sql,
+    concat_to_dpipe_sql,
     count_if_to_sum,
     no_ilike_sql,
     no_pivot_sql,
@@ -15,7 +18,7 @@ from sqlglot.dialects.dialect import (
 from sqlglot.tokens import TokenType
 
 
-def _date_add_sql(self, expression):
+def _date_add_sql(self: generator.Generator, expression: exp.DateAdd) -> str:
     modifier = expression.expression
     modifier = modifier.name if modifier.is_string else self.sql(modifier)
     unit = expression.args.get("unit")
@@ -58,17 +61,16 @@ def _transform_create(expression: exp.Expression) -> exp.Expression:
 
 
 class SQLite(Dialect):
+    # https://sqlite.org/forum/forumpost/5e575586ac5c711b?raw
+    RESOLVES_IDENTIFIERS_AS_UPPERCASE = None
+
     class Tokenizer(tokens.Tokenizer):
         IDENTIFIERS = ['"', ("[", "]"), "`"]
         HEX_STRINGS = [("x'", "'"), ("X'", "'"), ("0x", ""), ("0X", "")]
 
-        KEYWORDS = {
-            **tokens.Tokenizer.KEYWORDS,
-        }
-
     class Parser(parser.Parser):
         FUNCTIONS = {
-            **parser.Parser.FUNCTIONS,  # type: ignore
+            **parser.Parser.FUNCTIONS,
             "EDITDIST3": exp.Levenshtein.from_arg_list,
         }
 
@@ -77,7 +79,7 @@ class SQLite(Dialect):
         TABLE_HINTS = False
 
         TYPE_MAPPING = {
-            **generator.Generator.TYPE_MAPPING,  # type: ignore
+            **generator.Generator.TYPE_MAPPING,
             exp.DataType.Type.BOOLEAN: "INTEGER",
             exp.DataType.Type.TINYINT: "INTEGER",
             exp.DataType.Type.SMALLINT: "INTEGER",
@@ -99,7 +101,8 @@ class SQLite(Dialect):
         }
 
         TRANSFORMS = {
-            **generator.Generator.TRANSFORMS,  # type: ignore
+            **generator.Generator.TRANSFORMS,
+            exp.Concat: concat_to_dpipe_sql,
             exp.CountIf: count_if_to_sum,
             exp.Create: transforms.preprocess([_transform_create]),
             exp.CurrentDate: lambda *_: "CURRENT_DATE",
@@ -116,6 +119,7 @@ class SQLite(Dialect):
             exp.LogicalOr: rename_func("MAX"),
             exp.LogicalAnd: rename_func("MIN"),
             exp.Pivot: no_pivot_sql,
+            exp.SafeConcat: concat_to_dpipe_sql,
             exp.Select: transforms.preprocess(
                 [transforms.eliminate_distinct_on, transforms.eliminate_qualify]
             ),
@@ -131,8 +135,8 @@ class SQLite(Dialect):
 
         LIMIT_FETCH = "LIMIT"
 
-        def cast_sql(self, expression: exp.Cast) -> str:
-            if expression.to.this == exp.DataType.Type.DATE:
+        def cast_sql(self, expression: exp.Cast, safe_prefix: t.Optional[str] = None) -> str:
+            if expression.is_type("date"):
                 return self.func("DATE", expression.this)
 
             return super().cast_sql(expression)
@@ -165,12 +169,15 @@ class SQLite(Dialect):
             return f"CAST({sql} AS INTEGER)"
 
         # https://www.sqlite.org/lang_aggfunc.html#group_concat
-        def groupconcat_sql(self, expression):
+        def groupconcat_sql(self, expression: exp.GroupConcat) -> str:
             this = expression.this
             distinct = expression.find(exp.Distinct)
+
             if distinct:
                 this = distinct.expressions[0]
-                distinct = "DISTINCT "
+                distinct_sql = "DISTINCT "
+            else:
+                distinct_sql = ""
 
             if isinstance(expression.this, exp.Order):
                 self.unsupported("SQLite GROUP_CONCAT doesn't support ORDER BY.")
@@ -178,7 +185,7 @@ class SQLite(Dialect):
                     this = expression.this.this
 
             separator = expression.args.get("separator")
-            return f"GROUP_CONCAT({distinct or ''}{self.format_args(this, separator)})"
+            return f"GROUP_CONCAT({distinct_sql}{self.format_args(this, separator)})"
 
         def least_sql(self, expression: exp.Least) -> str:
             if len(expression.expressions) > 1:
