@@ -5,11 +5,9 @@ from collections import deque
 from decimal import Decimal
 
 from sqlglot import exp
-from sqlglot.generator import Generator
+from sqlglot.generator import cached_generator
 from sqlglot.helper import first, while_changing
 
-GENERATOR = Generator(normalize=True, identify="safe")
-
 
 def simplify(expression):
     """
@@ -27,12 +25,14 @@ def simplify(expression):
         sqlglot.Expression: simplified expression
     """
 
-    cache = {}
+    generate = cached_generator()
 
     def _simplify(expression, root=True):
+        if expression.meta.get("final"):
+            return expression
         node = expression
         node = rewrite_between(node)
-        node = uniq_sort(node, cache, root)
+        node = uniq_sort(node, generate, root)
         node = absorb_and_eliminate(node, root)
         exp.replace_children(node, lambda e: _simplify(e, False))
         node = simplify_not(node)
@@ -247,7 +247,7 @@ def remove_compliments(expression, root=True):
     return expression
 
 
-def uniq_sort(expression, cache=None, root=True):
+def uniq_sort(expression, generate, root=True):
     """
     Uniq and sort a connector.
 
@@ -256,7 +256,7 @@ def uniq_sort(expression, cache=None, root=True):
     if isinstance(expression, exp.Connector) and (root or not expression.same_parent):
         result_func = exp.and_ if isinstance(expression, exp.And) else exp.or_
         flattened = tuple(expression.flatten())
-        deduped = {GENERATOR.generate(e, cache): e for e in flattened}
+        deduped = {generate(e): e for e in flattened}
         arr = tuple(deduped.items())
 
         # check if the operands are already sorted, if not sort them
@@ -410,9 +410,14 @@ def remove_where_true(expression):
         if always_true(where.this):
             where.parent.set("where", None)
     for join in expression.find_all(exp.Join):
-        if always_true(join.args.get("on")):
-            join.set("kind", "CROSS")
+        if (
+            always_true(join.args.get("on"))
+            and not join.args.get("using")
+            and not join.args.get("method")
+        ):
             join.set("on", None)
+            join.set("side", None)
+            join.set("kind", "CROSS")
 
 
 def always_true(expression):
