@@ -15,14 +15,23 @@ class TestParser(unittest.TestCase):
         self.assertIsInstance(parse_one("left join foo", into=exp.Join), exp.Join)
         self.assertIsInstance(parse_one("int", into=exp.DataType), exp.DataType)
         self.assertIsInstance(parse_one("array<int>", into=exp.DataType), exp.DataType)
+        self.assertIsInstance(parse_one("foo", into=exp.Table), exp.Table)
+
+        with self.assertRaises(ParseError) as ctx:
+            parse_one("SELECT * FROM tbl", into=exp.Table)
+
+        self.assertEqual(
+            str(ctx.exception),
+            "Failed to parse 'SELECT * FROM tbl' into <class 'sqlglot.expressions.Table'>",
+        )
 
     def test_parse_into_error(self):
-        expected_message = "Failed to parse into [<class 'sqlglot.expressions.From'>]"
+        expected_message = "Failed to parse 'SELECT 1;' into [<class 'sqlglot.expressions.From'>]"
         expected_errors = [
             {
                 "description": "Invalid expression / Unexpected token",
                 "line": 1,
-                "col": 7,
+                "col": 6,
                 "start_context": "",
                 "highlight": "SELECT",
                 "end_context": " 1;",
@@ -30,17 +39,18 @@ class TestParser(unittest.TestCase):
             }
         ]
         with self.assertRaises(ParseError) as ctx:
-            parse_one("SELECT 1;", "sqlite", [exp.From])
+            parse_one("SELECT 1;", read="sqlite", into=[exp.From])
+
         self.assertEqual(str(ctx.exception), expected_message)
         self.assertEqual(ctx.exception.errors, expected_errors)
 
     def test_parse_into_errors(self):
-        expected_message = "Failed to parse into [<class 'sqlglot.expressions.From'>, <class 'sqlglot.expressions.Join'>]"
+        expected_message = "Failed to parse 'SELECT 1;' into [<class 'sqlglot.expressions.From'>, <class 'sqlglot.expressions.Join'>]"
         expected_errors = [
             {
                 "description": "Invalid expression / Unexpected token",
                 "line": 1,
-                "col": 7,
+                "col": 6,
                 "start_context": "",
                 "highlight": "SELECT",
                 "end_context": " 1;",
@@ -49,7 +59,7 @@ class TestParser(unittest.TestCase):
             {
                 "description": "Invalid expression / Unexpected token",
                 "line": 1,
-                "col": 7,
+                "col": 6,
                 "start_context": "",
                 "highlight": "SELECT",
                 "end_context": " 1;",
@@ -58,6 +68,7 @@ class TestParser(unittest.TestCase):
         ]
         with self.assertRaises(ParseError) as ctx:
             parse_one("SELECT 1;", "sqlite", [exp.From, exp.Join])
+
         self.assertEqual(str(ctx.exception), expected_message)
         self.assertEqual(ctx.exception.errors, expected_errors)
 
@@ -70,6 +81,11 @@ class TestParser(unittest.TestCase):
     def test_float(self):
         self.assertEqual(parse_one(".2"), parse_one("0.2"))
 
+    def test_unnest_projection(self):
+        expr = parse_one("SELECT foo IN UNNEST(bla) AS bar")
+        self.assertIsInstance(expr.selects[0], exp.Alias)
+        self.assertEqual(expr.selects[0].output_name, "bar")
+
     def test_unary_plus(self):
         self.assertEqual(parse_one("+15"), exp.Literal.number(15))
 
@@ -202,6 +218,15 @@ class TestParser(unittest.TestCase):
         with self.assertRaises(ParseError):
             parse_one("WITH cte AS (SELECT * FROM x)")
 
+        self.assertEqual(
+            parse_one(
+                "CREATE TABLE t (i UInt8) ENGINE = AggregatingMergeTree() ORDER BY tuple()",
+                read="clickhouse",
+                error_level=ErrorLevel.RAISE,
+            ).sql(dialect="clickhouse"),
+            "CREATE TABLE t (i UInt8) ENGINE=AggregatingMergeTree() ORDER BY tuple()",
+        )
+
     def test_space(self):
         self.assertEqual(
             parse_one("SELECT ROW() OVER(PARTITION  BY x) FROM x GROUP  BY y").sql(),
@@ -496,3 +521,11 @@ class TestParser(unittest.TestCase):
                 expr = parse_one(query, read=dialect)
                 columns = expr.args["from"].this.args["pivots"][0].args["columns"]
                 self.assertEqual(expected_columns, [col.sql(dialect=dialect) for col in columns])
+
+    def test_parse_properties(self):
+        self.assertEqual(
+            parse_one("create materialized table x").sql(), "CREATE MATERIALIZED TABLE x"
+        )
+
+    def test_parse_floats(self):
+        self.assertTrue(parse_one("1. ").is_number)
